
# Type: default_prefix


default and base prefix -- used for ':' identifiers, @base and @vocab

URI: [meta:default_prefix](https://w3id.org/biolink/biolinkml/meta/default_prefix)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
